@@ -1,29 +1,28 @@
-/* $XConsortium: AsciiSrc.c,v 1.55 91/07/25 18:09:27 rws Exp $ */
+/* $TOG: AsciiSrc.c /main/69 1998/05/14 14:55:34 kaleb $ */
 
 /*
- * Copyright 1989 Massachusetts Institute of Technology
- *
- * Permission to use, copy, modify, distribute, and sell this software and its
- * documentation for any purpose is hereby granted without fee, provided that
- * the above copyright notice appear in all copies and that both that
- * copyright notice and this permission notice appear in supporting
- * documentation, and that the name of M.I.T. not be used in advertising or
- * publicity pertaining to distribution of the software without specific,
- * written prior permission.  M.I.T. makes no representations about the
- * suitability of this software for any purpose.  It is provided "as is"
- * without express or implied warranty.
- *
- * M.I.T. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL M.I.T.
- * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
- * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN
- * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- *
- * Author:  Chris Peterson, MIT X Consortium.
- *
- * Much code taken from X11R3 String and Disk Sources.
- */
+
+Copyright 1989, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+This file contains modifications for XawPlus, Roland Krause 2000
+
+*/
 
 /*
  * AsciiSrc.c - AsciiSrc object. (For use with the text widget).
@@ -36,11 +35,16 @@
 #include <errno.h>
 #include <X11/StringDefs.h>
 #include <X11/Xos.h>
+#ifndef X_NOT_STDC_ENV
+#include <stdlib.h>
+#endif
 #include <X11/Xfuncs.h>
 #include <X11/XawPlus/XawInit.h>
 #include <X11/XawPlus/AsciiSrcP.h>
 #include <X11/Xmu/Misc.h>
 #include <X11/Xmu/CharSet.h>
+#include <X11/XawPlus/MultiSrcP.h> 
+
 
 #if (defined(ASCII_STRING) || defined(ASCII_DISK))
 #  include <X11/XawPlus/AsciiText.h> /* for Widget Classes. */
@@ -91,6 +95,17 @@ static void RemoveOldStringOrFile(),  CvtStringToAsciiType();
 static void ClassInitialize(), Initialize(), Destroy(), GetValuesHook();
 static String MyStrncpy(), StorePiecesInString();
 static Boolean SetValues(), WriteToFile();
+#ifdef X_NOT_STDC_ENV
+extern int errno;
+#endif
+
+#ifdef X_NOT_POSIX
+#define Off_t long
+#define Size_t unsigned int
+#else
+#define Off_t off_t
+#define Size_t size_t
+#endif
 
 #define superclass		(&textSrcClassRec)
 AsciiSrcClassRec asciiSrcClassRec = {
@@ -174,7 +189,9 @@ ClassInitialize()
  *      Returns: none.
  */
 
-static void Initialize(request, new, args, num_args)
+/* ARGSUSED */
+static void
+Initialize(request, new, args, num_args)
 Widget request, new;
 ArgList args;
 Cardinal *num_args;
@@ -186,6 +203,8 @@ Cardinal *num_args;
  * Set correct flags (override resources) depending upon widget class.
  */
 
+  src->text_src.text_format = XawFmt8Bit;	/* data format. */
+
 #ifdef ASCII_DISK
   if (XtIsSubclass(XtParent(new), asciiDiskWidgetClass)) {
     src->ascii_src.type = XawAsciiFile;
@@ -395,10 +414,10 @@ int     	      count;
 Boolean	              include;
 {
   AsciiSrcObject src = (AsciiSrcObject) w;
-  register int inc;
-  Piece * piece;
+  int inc;
+  Piece* piece;
   XawTextPosition first, first_eol_position;
-  register char * ptr;
+  char* ptr;
 
   if (type == XawstAll) {	/* Optomize this common case. */
     if (dir == XawsdRight)
@@ -440,8 +459,9 @@ Boolean	              include;
   case XawstWhiteSpace: 
     for ( ; count > 0 ; count-- ) {
       Boolean non_space = FALSE, first_eol = TRUE;
+      /* CONSTCOND */
       while (TRUE) {
-	register unsigned char c = *ptr;
+	unsigned char c = *ptr;
 
 	ptr += inc;
 	position += inc;
@@ -526,8 +546,8 @@ XawTextScanDirection  dir;
 XawTextBlock *        text;
 {
   AsciiSrcObject src = (AsciiSrcObject) w;
-  register int inc, count = 0;
-  register char * ptr;
+  int inc, count = 0;
+  char * ptr;
   Piece * piece;
   char * buf;
   XawTextPosition first;
@@ -541,11 +561,12 @@ XawTextBlock *        text;
     position--;
   }
 
-  buf = XtMalloc(sizeof(unsigned char) * text->length);
+  buf = XtMalloc((unsigned)sizeof(unsigned char) * text->length);
   strncpy(buf, (text->ptr + text->firstPos), text->length);
   piece = FindPiece(src, position, &first);
   ptr = (position - first) + piece->text;
 
+  /* CONSTCOND */
   while (TRUE) {
     if (*ptr == ((dir == XawsdRight) ? *(buf + count) 
 		                     : *(buf + text->length - count - 1)) ) {
@@ -598,7 +619,9 @@ XawTextBlock *        text;
  *	Returns: True if redisplay is needed.
  */
 
-static Boolean SetValues(current, request, new, args, num_args)
+/* ARGSUSED */
+static Boolean
+SetValues(current, request, new, args, num_args)
 Widget current, request, new;
 ArgList args;
 Cardinal * num_args;
@@ -663,7 +686,7 @@ ArgList args;
 Cardinal * num_args;
 {
   AsciiSrcObject src = (AsciiSrcObject) w;
-  register int i;
+  int i;
 
   if (src->ascii_src.type == XawAsciiString) {
     for (i = 0; i < *num_args ; i++ ) 
@@ -716,6 +739,19 @@ Widget w;
 {
   AsciiSrcObject src = (AsciiSrcObject) w;
 
+  /* If the src is really a multi, call the multi routine.*/
+
+  if ( XtIsSubclass( w, multiSrcObjectClass ) ) {
+      _XawMultiSourceFreeString( w );
+      return;
+  }
+
+  else if ( !XtIsSubclass( w, asciiSrcObjectClass ) ) {
+      XtErrorMsg("bad argument", "asciiSource", "XawError",
+            "XawAsciiSourceFreeString's parameter must be an asciiSrc or multiSrc.",
+	     NULL, NULL);
+  }
+
   if (src->ascii_src.allocated_string && src->ascii_src.type != XawAsciiFile) {
     src->ascii_src.allocated_string = FALSE;
     XtFree(src->ascii_src.string);
@@ -739,6 +775,17 @@ Widget w;
 {
   AsciiSrcObject src = (AsciiSrcObject) w;
 
+  /* If the src is really a multi, call the multi save. */
+
+  if ( XtIsSubclass( w, multiSrcObjectClass ) )
+      return( _XawMultiSave( w ) );
+
+  else if ( !XtIsSubclass( w, asciiSrcObjectClass ) ) {
+      	XtErrorMsg("bad argument", "asciiSource", "XawError",
+		"XawAsciiSave's parameter must be an asciiSrc or multiSrc.",
+		   NULL, NULL);
+  }
+
 /*
  * If using the string in place then there is no need to play games
  * to get the internal info into a readable string.
@@ -793,6 +840,17 @@ String name;
   String string;
   Boolean ret;
 
+  /* If the src is really a multi, call the multi save. - */
+
+  if ( XtIsSubclass( w, multiSrcObjectClass ) )
+      return( _XawMultiSaveAsFile( w, name ) );
+
+  else if ( !XtIsSubclass( w, asciiSrcObjectClass ) ) {
+      	XtErrorMsg("bad argument", "asciiSource", "XawError",
+		"XawAsciiSaveAsFile's 1st parameter must be an asciiSrc or multiSrc.",
+		   NULL, NULL);
+  }
+
   string = StorePiecesInString(src); 
 
   ret = WriteToFile(string, name);
@@ -814,7 +872,17 @@ XawAsciiSourceChanged(w)
 Widget w;
 #endif
 {
-  return( ((AsciiSrcObject) w)->ascii_src.changes );
+  if ( XtIsSubclass( w, multiSrcObjectClass ) )
+      return( ( (MultiSrcObject) w )->multi_src.changes );
+
+  if ( XtIsSubclass( w, asciiSrcObjectClass ) )
+      return( ( (AsciiSrcObject) w)->ascii_src.changes );
+
+  XtErrorMsg("bad argument", "asciiSource", "XawError",
+		"XawAsciiSourceChanged parameter must be an asciiSrc or multiSrc.",
+		   NULL, NULL);
+
+  return( True ); /* for gcc -Wall */
 }
   
 /************************************************************
@@ -875,7 +943,8 @@ AsciiSrcObject src;
   XawTextPosition first;
   Piece * piece;
 
-  string = XtMalloc(sizeof(unsigned char) * src->ascii_src.length + 1);
+  string = XtMalloc((unsigned) sizeof(unsigned char) * 
+		    src->ascii_src.length + 1);
   
   for (first = 0, piece = src->ascii_src.first_piece ; piece != NULL; 
        first += piece->used, piece = piece->next) 
@@ -978,21 +1047,15 @@ Boolean newString;
     
     if (!src->ascii_src.is_tempfile) {
 	if ((file = fopen(src->ascii_src.string, open_mode)) != 0) {
-	    (void) fseek(file, 0L, 2);
-	    src->ascii_src.length = ftell(file);
+	    (void) fseek(file, (Off_t)0, 2);
+	    src->ascii_src.length = (XawTextPosition) ftell(file);
 	    return file;
 	} else {
 	    String params[2];
 	    Cardinal num_params = 2;
-	    char msg[11];
 	    
 	    params[0] = src->ascii_src.string;
-	    if (errno <= sys_nerr)
-		params[1] = sys_errlist[errno];
-	    else {
-		sprintf(msg, "errno=%.4d", errno);
-		params[1] = msg;
-	    }
+	    params[1] = strerror(errno);
 	    XtAppWarningMsg(XtWidgetToApplicationContext((Widget)src),
 			    "openError", "asciiSourceCreate", "XawWarning",
 			    "Cannot open file %s; %s", params, &num_params);
@@ -1009,16 +1072,18 @@ FILE * file;
 char * string;
 {
   char *local_str, *ptr;
-  register Piece * piece = NULL;
+  Piece * piece = NULL;
   XawTextPosition left;
 
   if (string == NULL) {
     if (src->ascii_src.type == XawAsciiFile) {
-      local_str = XtMalloc((src->ascii_src.length + 1) *sizeof(unsigned char));
+      local_str = XtMalloc((unsigned) (src->ascii_src.length + 1) 
+			   * sizeof(unsigned char));
       if (src->ascii_src.length != 0) {
-	fseek(file, 0L, 0);
-	if ( fread(local_str, sizeof(unsigned char),
-		   src->ascii_src.length, file) != src->ascii_src.length ) 
+	fseek(file, (Off_t)0, 0);
+	src->ascii_src.length = fread(local_str, (Size_t)sizeof(unsigned char),
+				      (Size_t)src->ascii_src.length, file);
+	if (src->ascii_src.length <= 0)
 	  XtErrorMsg("readError", "asciiSourceCreate", "XawError",
 		     "fread returned error.", NULL, NULL);
       }
@@ -1050,7 +1115,8 @@ char * string;
   do {
     piece = AllocNewPiece(src, piece);
 
-    piece->text = XtMalloc(src->ascii_src.piece_size * sizeof(unsigned char));
+    piece->text = XtMalloc((unsigned)src->ascii_src.piece_size
+			   * sizeof(unsigned char));
     piece->used = Min(left, src->ascii_src.piece_size);
     if (piece->used != 0)
       strncpy(piece->text, ptr, piece->used);
@@ -1106,7 +1172,7 @@ AsciiSrcObject src;
   Piece * next, * first = src->ascii_src.first_piece;
 
   if (first->prev != NULL)
-    printf("Programmer Botch in FreeAllPieces, there may be a memory leak.\n");
+    (void) printf("Xaw AsciiSrc Object: possible memory leak in FreeAllPieces().\n");
 
   for ( ; first != NULL ; first = next ) {
     next = first->next;
@@ -1153,7 +1219,7 @@ FindPiece(src, position, first)
 AsciiSrcObject src;
 XawTextPosition position, *first;
 {
-  Piece *piece = src->ascii_src.first_piece, *old_piece = piece;
+  Piece * old_piece, * piece = src->ascii_src.first_piece;
   XawTextPosition temp;
 
   for ( temp = 0 ; piece != NULL ; temp += piece->used, piece = piece->next ) {
@@ -1179,12 +1245,19 @@ MyStrncpy(s1, s2, n)
 char * s1, * s2;
 int n;
 {
-  char * temp = XtMalloc(sizeof(unsigned char) * n);
+  char buf[256];
+  char* temp;
+
+  if (n == 0) return s1;
+
+  if (n < sizeof buf) temp = buf;
+  else temp = XtMalloc((unsigned)sizeof(unsigned char) * n);
 
   strncpy(temp, s2, n);		/* Saber has a bug that causes it to generate*/
   strncpy(s1, temp, n);		/* a bogus warning message here (CDP 6/32/89)*/
-  XtFree(temp);
-  return(s1);
+
+  if (temp != buf) XtFree(temp);
+  return s1;
 }
   
 /*	Function Name: BreakPiece
@@ -1213,7 +1286,7 @@ Piece * piece;
 /* ARGSUSED */
 static void
 CvtStringToAsciiType(args, num_args, fromVal, toVal)
-XrmValuePtr *args;		/* unused */
+XrmValuePtr 	args;		/* unused */
 Cardinal	*num_args;	/* unused */
 XrmValuePtr	fromVal;
 XrmValuePtr	toVal;
@@ -1222,22 +1295,30 @@ XrmValuePtr	toVal;
   static XrmQuark  XtQEstring = NULLQUARK;
   static XrmQuark  XtQEfile;
   XrmQuark q;
-  char lowerName[BUFSIZ];
+  char lowerName[40];
 
   if (XtQEstring == NULLQUARK) {
     XtQEstring = XrmPermStringToQuark(XtEstring);
     XtQEfile   = XrmPermStringToQuark(XtEfile);
   }
 
-  XmuCopyISOLatin1Lowered(lowerName, (char *) fromVal->addr);
-  q = XrmStringToQuark(lowerName);
+  if (strlen ((char*)fromVal->addr) < sizeof lowerName) {
+    XmuCopyISOLatin1Lowered(lowerName, (char *) fromVal->addr);
+    q = XrmStringToQuark(lowerName);
 
-  if (q == XtQEstring) type = XawAsciiString;
-  if (q == XtQEfile)  type = XawAsciiFile;
-
-  (*toVal).size = sizeof(XawAsciiType);
-  (*toVal).addr = (XPointer) &type;
-  return;
+    if (q == XtQEstring)     type = XawAsciiString;
+    else if (q == XtQEfile)  type = XawAsciiFile;
+    else {
+      toVal->size = 0;
+      toVal->addr = NULL;
+      return;
+    }
+    toVal->size = sizeof type;
+    toVal->addr = (XPointer) &type;
+    return;
+  }
+  toVal->size = 0;
+  toVal->addr = NULL;
 }
 
 #if (defined(ASCII_STRING) || defined(ASCII_DISK))
@@ -1313,7 +1394,7 @@ Cardinal num_args;
   XawTextSource src;
   ArgList ascii_args;
   Arg temp[1];
-  register int i;
+  int i;
 
   XtSetArg(temp[0], XtNtype, XawAsciiFile);
   ascii_args = XtMergeArgLists(temp, ONE, args, num_args);
