@@ -1,8 +1,27 @@
-/* $XConsortium: Command.c,v 1.76 91/05/04 19:29:00 converse Exp $ */
+/* $TOG: Command.c /main/80 1998/02/06 12:45:20 kaleb $ */
 
-/***********************************************************
-Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,
-and the Massachusetts Institute of Technology, Cambridge, Massachusetts.
+/************************************************************************
+
+Copyright 1987, 1988, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+
+Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
@@ -10,7 +29,7 @@ Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
 both that copyright notice and this permission notice appear in 
-supporting documentation, and that the names of Digital or MIT not be
+supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
 software without specific, written prior permission.  
 
@@ -22,13 +41,9 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
-3D extensions added and extensively redesigned: Roland Krause 1996
-Tooltip function added: Roland Krause 1998
-Redesign for KDE styled buttons: Roland Krause 1999
-Adaption to the new Add3dExt concept: Roland Krause 1999
-New mechanism to truncate long label strings : Roland Krause 1999
+This file contains EXTENSIVE modifications for XawPlus, Roland Krause 1996 - 2000
 
-******************************************************************/
+*************************************************************************/
 
 /*
  * Command.c - Command button widget
@@ -63,8 +78,6 @@ static XtResource resources[] = {
 	offset(core.border_width),  XtRImmediate, (XtPointer)0},
    {XtNhelpText, XtCLabel, XtRString, sizeof(String),
 	offset(command.helpText), XtRString, NULL},
-   {XtNhelpEncoding, XtCEncoding, XtRUnsignedChar, sizeof(unsigned char),
-	offset(command.helpEncoding), XtRImmediate, (XtPointer)XawTextEncoding8bit},
    {XtNuseHelp, XtCBoolean, XtRBoolean, sizeof(Boolean),
 	offset(command.useHelp), XtRImmediate, (XtPointer)True},
   {XtNhelpBackground, XtCBackground, XtRPixel, sizeof(Pixel),
@@ -130,9 +143,6 @@ CommandClassRec commandClassRec = {
     XtInheritDisplayAccelerator,	/* display_accelerator	  */
     NULL				/* extension		  */
   },  /* CoreClass fields initialization */
-  {
-    0					/* unused		*/
-  },  /* add3dExt fields initialization */
   {
     XtInheritChangeSensitive		/* change_sensitive	*/
   },  /* SimpleClass fields initialization */
@@ -190,14 +200,14 @@ CommandWidget cbw;
 {
   return(LEFT_OFFSET(cbw) + cbw->label.label_width +
 	 2*(cbw->label.internal_width + cbw->command.highlight_thickness +
-	   cbw->add3dExt.borderWidth));
+	   cbw->simple.borderWidth));
 }
 
 static Dimension CalcHeight(cbw)
 CommandWidget cbw;
 {
   return(cbw->label.label_height + 2*(cbw->label.internal_height +
-	 cbw->command.highlight_thickness + cbw->add3dExt.borderWidth));
+	 cbw->command.highlight_thickness + cbw->simple.borderWidth));
 }
 
 /***********************************************************************
@@ -218,21 +228,21 @@ Widget current, new;
   Position newPos, leftedge;
 
   leftedge = LEFT_OFFSET(cbw) + cbw->label.internal_width +
-	     cbw->command.highlight_thickness + cbw->add3dExt.borderWidth;
-  switch (cbw->label.justify) {
-
+	     cbw->command.highlight_thickness + cbw->simple.borderWidth;
+  switch (cbw->label.justify)
+  {
 	case XtJustifyLeft:
 	    newPos = leftedge;
 	    break;
 
 	case XtJustifyRight:
 	    newPos = current->core.width - cbw->label.label_width - cbw->label.internal_width -
-		     cbw->command.highlight_thickness - cbw->add3dExt.borderWidth;
+		     cbw->command.highlight_thickness - cbw->simple.borderWidth;
 	    break;
 
 	case XtJustifyCenter:
 	default:
-	    newPos = (Position)((current->core.width - cbw->label.label_width)/2);
+	    newPos = (Position)(current->core.width - cbw->label.label_width /* + LEFT_OFFSET(cbw)*/)/2;
 	    break;
   }
   /* Justify the label on the left side, if there is not enough space
@@ -251,7 +261,7 @@ Widget current, new;
 	cbw->label.lbm_y = (int)((current->core.height - cbw->label.lbm_height)/2 -
 			         cbw->label.internal_height);
 	cbw->label.lbm_x = (int)(cbw->label.internal_width + cbw->command.highlight_thickness +
-				 cbw->add3dExt.borderWidth);
+				 cbw->simple.borderWidth);
     }
     else
     {
@@ -296,7 +306,6 @@ CommandWidget cw;
 
   cw->command.helpLabel = XtVaCreateManagedWidget("helpLabel",
 				labelWidgetClass, cw->command.helpWidget,
-				XtNencoding, cw->command.helpEncoding,
 				XtNtruncLabel, False,
 				XtNlabel, cw->command.helpText,
 				XtNbackground, cw->command.helpBackground, NULL);
@@ -368,7 +377,7 @@ Cardinal *num_args;		/* unused */
 
   /* Calculate the correct size of the widget */
 
-  Add = 2 * (cbw->add3dExt.borderWidth + cbw->command.highlight_thickness);
+  Add = 2 * (cbw->simple.borderWidth + cbw->command.highlight_thickness);
   OldWidth = cbw->core.width;
   cbw->core.width  += Add;
   cbw->core.height += Add;
@@ -429,7 +438,7 @@ Widget w;
 
   RepositionLabel(w, w);
   if (cbw->label.truncLabel)
-    TruncateLabelString((LabelWidget)w, width - 2*cbw->add3dExt.borderWidth -
+    TruncateLabelString((LabelWidget)w, width - 2*cbw->simple.borderWidth -
     			 LEFT_OFFSET(cbw));
 
   if (XtIsRealized(w) && (cbw->command.highlightMode == FALSE)) 
@@ -515,7 +524,7 @@ Cardinal *num_args;
     RepositionLabel(current, new);
     if (cbw->label.truncLabel)
       TruncateLabelString((LabelWidget)new, oldcbw->core.width -
-        2*(cbw->add3dExt.borderWidth + cbw->command.highlight_thickness) -
+        2*(cbw->simple.borderWidth + cbw->command.highlight_thickness) -
 	LEFT_OFFSET(cbw));
 
     redisplay = TRUE;
@@ -728,9 +737,9 @@ XtWidgetGeometry *intended, *preferred;
 
   preferred->request_mode = CWWidth | CWHeight;
   preferred->width = cbw->label.label_width + 2*cbw->label.internal_width + LEFT_OFFSET(cbw) +
-		     2*cbw->add3dExt.borderWidth + 2*cbw->command.highlight_thickness;
+		     2*cbw->simple.borderWidth + 2*cbw->command.highlight_thickness;
   preferred->height= cbw->label.label_height + 2*cbw->label.internal_height +
-		     2*cbw->add3dExt.borderWidth + 2*cbw->command.highlight_thickness;
+		     2*cbw->simple.borderWidth + 2*cbw->command.highlight_thickness;
 
   /* Now let us see, if the geometry request is acceptable in any way */
 
