@@ -1,8 +1,27 @@
-/* $XConsortium: Form.c,v 1.48 91/07/22 18:08:25 ackerman Exp $ */
+/* $TOG: Form.c /main/54 1998/05/14 14:55:45 kaleb $ */
 
-/***********************************************************
-Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,
-and the Massachusetts Institute of Technology, Cambridge, Massachusetts.
+/**************************************************************************
+
+Copyright 1987, 1988, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+
+Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
@@ -10,7 +29,7 @@ Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
 both that copyright notice and this permission notice appear in 
-supporting documentation, and that the names of Digital or MIT not be
+supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
 software without specific, written prior permission.  
 
@@ -22,9 +41,9 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
-Usage of color converter for background color added: Roland Krause 1997
+This file contains modifications for XawPlus, Roland Krause 2000
 
-******************************************************************/
+***************************************************************************/
 
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
@@ -146,12 +165,6 @@ WidgetClass formWidgetClass = (WidgetClass)&formClassRec;
 static XrmQuark	XtQChainLeft, XtQChainRight, XtQChainTop,
 		XtQChainBottom, XtQRubber;
 
-#define	done(address, type) \
-	{ toVal->size = sizeof(type); \
-	  toVal->addr = (caddr_t) address; \
-	  return; \
-	}
-
 /* ARGSUSED */
 static void _CvtStringToEdgeType(args, num_args, fromVal, toVal)
     XrmValuePtr args;		/* unused */
@@ -159,35 +172,29 @@ static void _CvtStringToEdgeType(args, num_args, fromVal, toVal)
     XrmValuePtr fromVal;
     XrmValuePtr toVal;
 {
-    static XtEdgeType edgeType;
-    XrmQuark q;
-    char lowerName[1000];
+  static XtEdgeType edgeType;
+  XrmQuark q;
+  char lowerName[40];
 
+  if (strlen ((char*) fromVal->addr) < sizeof lowerName) {
     XmuCopyISOLatin1Lowered (lowerName, (char*)fromVal->addr);
     q = XrmStringToQuark(lowerName);
-    if (q == XtQChainLeft) {
-	edgeType = XtChainLeft;
-	done(&edgeType, XtEdgeType);
+    if (q == XtQChainLeft)        edgeType = XtChainLeft;
+    else if (q == XtQChainRight)  edgeType = XtChainRight;
+    else if (q == XtQChainTop)    edgeType = XtChainTop;
+    else if (q == XtQChainBottom) edgeType = XtChainBottom;
+    else if (q == XtQRubber)      edgeType = XtRubber;
+    else {
+      toVal->size = 0;
+      toVal->addr = NULL;
+      return;
     }
-    if (q == XtQChainRight) {
-	edgeType = XtChainRight;
-	done(&edgeType, XtEdgeType);
-    }
-    if (q == XtQChainTop) {
-	edgeType = XtChainTop;
-	done(&edgeType, XtEdgeType);
-    }
-    if (q == XtQChainBottom) {
-	edgeType = XtChainBottom;
-	done(&edgeType, XtEdgeType);
-    }
-    if (q == XtQRubber) {
-	edgeType = XtRubber;
-	done(&edgeType, XtEdgeType);
-    }
-    XtStringConversionWarning(fromVal->addr, "edgeType");
-    toVal->addr = NULL;
-    toVal->size = 0;
+    toVal->size = sizeof edgeType;
+    toVal->addr = (XPointer) &edgeType;
+    return;
+  }
+  toVal->addr = NULL;
+  toVal->size = 0;
 }
 
 static void ClassInitialize()
@@ -217,15 +224,15 @@ static void ClassInitialize()
 static void ClassPartInitialize(class)
     WidgetClass class;
 {
-    register FormWidgetClass c = (FormWidgetClass)class;
-    register FormWidgetClass super = (FormWidgetClass) 
+    FormWidgetClass c = (FormWidgetClass)class;
+    FormWidgetClass super = (FormWidgetClass) 
 	c->core_class.superclass;
 
     if (c->form_class.layout == XtInheritLayout)
 	c->form_class.layout = super->form_class.layout;
 }
 
-
+/* ARGSUSED */
 static void Initialize(request, new, args, num_args)
 Widget request, new;
 ArgList args;
@@ -333,8 +340,8 @@ static Boolean Layout(fw, width, height, force_relayout)
     maxx = maxy = 1;
     for (childP = children; childP - children < num_children; childP++) {
 	if (XtIsManaged(*childP)) {
-	    register FormConstraints form;
-	    register Position x, y;
+	    FormConstraints form;
+	    Position x, y;
 
 	    form = (FormConstraints)(*childP)->core.constraints;
 
@@ -358,8 +365,9 @@ static Boolean Layout(fw, width, height, force_relayout)
     if (fw->form.resize_in_layout) {
 	Boolean always_resize_children;
 
-	always_resize_children = ChangeFormGeometry( (Widget) fw, FALSE,
-						    maxx, maxy, NULL, NULL);
+	always_resize_children = 
+	    ChangeFormGeometry( (Widget) fw, FALSE, maxx, maxy, 
+				(Dimension *)NULL, (Dimension *)NULL);
 
 	fw->form.old_width  = fw->core.width;
 	fw->form.old_height = fw->core.height;
@@ -469,7 +477,7 @@ static void LayoutChild(w)
 
 
 static Position TransformCoord(loc, old, new, type)
-    register Position loc;
+    Position loc;
     Dimension old, new;
     XtEdgeType type;
 {
@@ -658,6 +666,7 @@ static XtGeometryResult GeometryManager(w, request, reply)
 }
 
 
+/* ARGSUSED */
 static Boolean SetValues(current, request, new, args, num_args)
 Widget current, request, new;
 ArgList args;
@@ -668,8 +677,10 @@ Cardinal *num_args;
 
 
 /* ARGSUSED */
-static void ConstraintInitialize(request, new)
+static void ConstraintInitialize(request, new, args, num_args)
     Widget request, new;
+    ArgList args;
+    Cardinal *num_args;
 {
     FormConstraints form = (FormConstraints)new->core.constraints;
     FormWidget fw = (FormWidget)new->core.parent;
@@ -686,14 +697,14 @@ static void ConstraintInitialize(request, new)
     form->form.deferred_resize = False;
 }
 
-
+/*ARGSUSED*/
 static Boolean ConstraintSetValues(current, request, new, args, num_args)
 Widget current, request, new;
 ArgList args;
 Cardinal *num_args;
 {
-  register FormConstraints cfc = (FormConstraints) current->core.constraints;
-  register FormConstraints nfc = (FormConstraints) new->core.constraints;
+  FormConstraints cfc = (FormConstraints) current->core.constraints;
+  FormConstraints nfc = (FormConstraints) new->core.constraints;
   
   if (cfc->form.top          != nfc->form.top         ||
       cfc->form.bottom       != nfc->form.bottom      ||
@@ -804,16 +815,16 @@ Widget w;
 Boolean doit;
 #endif
 {
-    register Widget *childP;
-    register FormWidget fw = (FormWidget)w;
-    register int num_children = fw->composite.num_children;
-    register WidgetList children = fw->composite.children;
+    Widget *childP;
+    FormWidget fw = (FormWidget)w;
+    int num_children = fw->composite.num_children;
+    WidgetList children = fw->composite.children;
 
     if ( ((fw->form.no_refigure = !doit) == TRUE) || !XtIsRealized(w) )
 	return;
 
     for (childP = children; childP - children < num_children; childP++) {
-	register Widget w = *childP;
+	Widget w = *childP;
 	if (XtIsManaged(w)) {
 	    FormConstraints form = (FormConstraints)w->core.constraints;
 
