@@ -1,8 +1,27 @@
-/* $XConsortium: Paned.c,v 1.23 91/07/21 18:56:15 gildea Exp $ */
+/* $TOG: Paned.c /main/29 1998/02/11 14:53:59 kaleb $ */
 
-/***********************************************************
-Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,
-and the Massachusetts Institute of Technology, Cambridge, Massachusetts.
+/*************************************************************************
+
+Copyright 1987, 1988, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+
+Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
@@ -10,7 +29,7 @@ Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
 both that copyright notice and this permission notice appear in 
-supporting documentation, and that the names of Digital or MIT not be
+supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
 software without specific, written prior permission.  
 
@@ -22,7 +41,7 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
-******************************************************************/
+***************************************************************************/
 
 /*
  * Paned.c - Paned Composite Widget.
@@ -35,7 +54,7 @@ SOFTWARE.
  *          MIT X Consortium
  *          kit@expo.lcs.mit.edu
  *
- * 3D extensions added : Roland Krause 1997
+ * This file contains modifications for XawPlus, Roland Krause 2000
  */
 
 #include <X11/IntrinsicP.h>
@@ -49,6 +68,10 @@ SOFTWARE.
 #include <X11/XawPlus/Grip.h>
 #include <X11/XawPlus/PanedP.h>
 
+/* I don't know why Paned.c calls _XawImCallVendorShellExtResize, but... */
+
+#include <X11/Xaw/XawImP.h> 
+
 #include <ctype.h>
 
 typedef enum {UpLeftPane = 'U', LowRightPane = 'L', 
@@ -295,6 +318,7 @@ Dimension * on_size_ret, * off_size_ret;
       request.request_mode |= XtCWQueryOnly;
 
       *result_ret = XtMakeGeometryRequest( (Widget) pw, &request, &reply );
+      _XawImCallVendorShellExtResize( (Widget) pw );
 
       if ( (newsize == old_size) || (*result_ret == XtGeometryNo) ) {
 	  *on_size_ret = old_size;
@@ -390,8 +414,10 @@ Boolean shrink;
 					   backwards. */
     }
     childP = pw->composite.children + _index;
+
+    /* CONSTCOND */
     while(TRUE) {
-        register Pane pane = PaneInfo(*childP);
+        Pane pane = PaneInfo(*childP);
         
         if ( (rules < 3 || SatisfiesRule3(pane, shrink)) &&
 	     (rules < 2 || SatisfiesRule2(pane))         &&
@@ -556,7 +582,7 @@ PanedWidget pw;
 int paneindex;
 Direction dir;
 {
-    register Widget *childP;
+    Widget *childP;
     int pane_size = (int) PaneSize( (Widget) pw, IsVert(pw) );
     int sizeused = 0;
     Position loc = 0;
@@ -568,7 +594,7 @@ Direction dir;
  */
 
     ForAllPanes(pw, childP) {
-        register Pane pane = PaneInfo(*childP);
+        Pane pane = PaneInfo(*childP);
 	AssignMax(pane->size, (int) pane->min);
 	AssignMin(pane->size, (int) pane->max);
 	sizeused += (int) pane->size + 2 * (int)pw->paned.internal_bw;
@@ -613,14 +639,14 @@ Direction dir;
 static void CommitNewLocations(pw)
 PanedWidget pw;
 {
-    register Widget *childP;
+    Widget *childP;
     XWindowChanges changes;
 
     changes.stack_mode = Above;
 
     ForAllPanes(pw, childP) {
-	register Pane pane = PaneInfo(*childP);
-	register Widget grip = pane->grip; /* may be NULL. */
+	Pane pane = PaneInfo(*childP);
+	Widget grip = pane->grip; /* may be NULL. */
 
 	if (IsVert(pw)) {
 	    XtMoveWidget(*childP, (Position) 0, pane->delta);
@@ -1389,7 +1415,7 @@ XtWidgetGeometry *request, *reply;
     XtGeometryMask mask = request->request_mode;
     Dimension old_size, old_wpsize, old_paned_size;
     Pane pane = PaneInfo(w);
-    register Boolean vert = IsVert(pw);
+    Boolean vert = IsVert(pw);
     Dimension on_size, off_size;
     XtGeometryResult result;
     Boolean almost = FALSE;
@@ -1466,7 +1492,7 @@ XtWidgetGeometry *request, *reply;
 	    request->height = w->core.height;
 
     almost = GetRequestInfo(request, !vert) != GetRequestInfo(reply, !vert);
-    almost |= GetRequestInfo(request, vert) != GetRequestInfo(reply, vert);
+    almost |= (GetRequestInfo(request, vert) != GetRequestInfo(reply, vert));
 
     if ( (mask & XtCWQueryOnly) || almost ) {
 	pane->wp_size = old_wpsize;
@@ -1476,7 +1502,9 @@ XtWidgetGeometry *request, *reply;
 	if (almost) return XtGeometryAlmost;
     }
     else {
-        AdjustPanedSize(pw, PaneSize((Widget) pw, !vert), NULL, NULL, NULL);
+        AdjustPanedSize(pw, PaneSize((Widget) pw, !vert), 
+			(XtGeometryResult *)NULL, 
+			(Dimension *)NULL, (Dimension *)NULL);
 	CommitNewLocations( pw );	/* layout already refigured. */
     }
     return XtGeometryDone;
@@ -1542,7 +1570,7 @@ XSetWindowAttributes *attributes;
 static void ReleaseGCs(w)
 Widget w;
 {
-    register PanedWidget pw = (PanedWidget)w;
+    PanedWidget pw = (PanedWidget)w;
 
     XtReleaseGC( w, pw->paned.highGC);
     XtReleaseGC( w, pw->paned.shadowGC);
@@ -1551,7 +1579,7 @@ Widget w;
 } 
 
 static void InsertChild(w)
-register Widget w;
+Widget w;
 {
    Pane pane = PaneInfo(w);
 
@@ -1598,7 +1626,7 @@ static void ChangeManaged(w)
    PanedWidget pw = (PanedWidget)w;
    Boolean vert = IsVert(pw);
    Dimension size;
-   register Widget *childP;
+   Widget *childP;
 
    if (pw->paned.recursively_called++) return;
 
@@ -1637,7 +1665,8 @@ static void ChangeManaged(w)
  */
 
    if ( PaneSize((Widget) pw, vert) == 0 ) 
-       AdjustPanedSize(pw, size, NULL, NULL, NULL);
+       AdjustPanedSize(pw, size, (XtGeometryResult *)NULL, 
+			(Dimension *)NULL, (Dimension *)NULL);
 
    if (XtIsRealized( (Widget) pw)) 
        RefigureLocationsAndCommit( (Widget) pw); 
@@ -1723,7 +1752,8 @@ Cardinal *num_args;
 
     if (old_pw->paned.internal_bw != new_pw->paned.internal_bw) {
         AdjustPanedSize( new_pw, PaneSize(new, !IsVert(old_pw)),
-			 NULL, NULL, NULL);
+			 (XtGeometryResult *)NULL, 
+			 (Dimension *)NULL, (Dimension *)NULL);
         RefigureLocationsAndCommit(new);
 	return(TRUE);		/* We have done a full configuration, return.*/
     }
