@@ -1,24 +1,23 @@
-/* $XConsortium: SimpleMenu.c,v 1.41 92/09/10 16:25:07 converse Exp $ */
+/* $TOG: SimpleMenu.c /main/47 1998/06/24 11:53:33 kaleb $ */
 
 /*
- * Copyright 1989 Massachusetts Institute of Technology
- *
- * Permission to use, copy, modify, distribute, and sell this software and its
- * documentation for any purpose is hereby granted without fee, provided that
- * the above copyright notice appear in all copies and that both that
- * copyright notice and this permission notice appear in supporting
- * documentation, and that the name of M.I.T. not be used in advertising or
- * publicity pertaining to distribution of the software without specific,
- * written prior permission.  M.I.T. makes no representations about the
- * suitability of this software for any purpose.  It is provided "as is"
- * without express or implied warranty.
- *
- * M.I.T. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL M.I.T.
- * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
- * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
- * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+Copyright 1989, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
  */
 
 /*
@@ -30,9 +29,7 @@
  *          MIT X Consortium 
  *          kit@expo.lcs.mit.edu
  *
- * 3D extensions added : Roland Krause 1997
- * It is not possible to make this widget to a child off `add3dExt'.
- * So this source shares a lot of code with Add3dExt.c.
+ * This file contains modifications for XawPlus, Roland Krause 2000
  */
 
 #include <stdio.h>
@@ -43,7 +40,7 @@
 #include <X11/XawPlus/XawInit.h>
 #include <X11/XawPlus/SimpleMenP.h>
 #include <X11/XawPlus/SmeBSB.h>
-#include <X11/XawPlus/Add3dExt.h>	/* Resource names needed */
+#include <X11/XawPlus/Simple.h>	/* Resource names needed */
 
 #include <X11/Xmu/Initer.h>
 #include <X11/Xmu/CharSet.h>
@@ -200,6 +197,12 @@ SimpleMenuClassRec simpleMenuClassRec = {
 
 WidgetClass simpleMenuWidgetClass = (WidgetClass)&simpleMenuClassRec;
 
+#define ForAllChildren(smw, childP) \
+  for ( (childP) = (SmeObject *) (smw)->composite.children ; \
+        (childP) < (SmeObject *) ( (smw)->composite.children + \
+				 (smw)->composite.num_children ) ; \
+        (childP)++ )
+
 /************************************************************
  *
  * Semi-Public Functions.
@@ -281,7 +284,7 @@ Cardinal *num_args;
 
   if (smw->core.width == 0) {
       smw->simple_menu.menu_width = FALSE;
-      smw->core.width = GetMenuWidth(new, NULL);
+      smw->core.width = GetMenuWidth(new, (Widget)NULL);
   }
 
   smw->simple_menu.menu_height = TRUE;
@@ -305,7 +308,7 @@ Cardinal *num_args;
  * Add a popup_callback routine for changing the cursor.
  */
   
-  XtAddCallback(new, XtNpopupCallback, ChangeCursorOnGrab, NULL);
+  XtAddCallback(new, XtNpopupCallback, ChangeCursorOnGrab, (XtPointer)NULL);
 }
 
 /*      Function Name: Redisplay
@@ -506,7 +509,7 @@ Widget w;
 ArgList arglist;
 Cardinal *num_args;
 {
-    register Cardinal i;
+    Cardinal i;
     Dimension width, height;
     
     width = w->core.width;
@@ -576,7 +579,7 @@ XtWidgetGeometry * request, * reply;
 	    entry->rectangle.height = old_height;	
 	}
 	else {
-	    Layout(( Widget) smw, NULL, NULL);
+	    Layout(( Widget) smw, (Dimension *)NULL, (Dimension *)NULL);
 	}
 	answer = XtGeometryDone;
     }
@@ -610,7 +613,7 @@ XtWidgetGeometry * request, * reply;
 static void ChangeManaged(w)
 Widget w;
 {
-    Layout(w, NULL, NULL);
+    Layout(w, (Dimension *)NULL, (Dimension *)NULL);
 }
 
 /************************************************************
@@ -639,21 +642,29 @@ Cardinal * num_params;
 { 
   Widget menu;
   XPoint loc;
+  char error_buf[BUFSIZ];
+  char* ebp;
+  int len;
+  char* fmt = "Xaw SimpleMenuWidget: could not find menu named: \"%s\"";
 
   if (*num_params != 1) {
-    char error_buf[BUFSIZ];
-    sprintf(error_buf, "%s %s",
-	    "Xaw - SimpleMenuWidget: position menu action expects only one",
-	    "parameter which is the name of the menu.");
-    XtAppWarning(XtWidgetToApplicationContext(w), error_buf);
+    XtAppWarning(XtWidgetToApplicationContext(w),
+		"Xaw - SimpleMenuWidget: position menu action expects only one\n"
+		"parameter, which is the name of the menu.");
     return;
   }
 
   if ( (menu = FindMenu(w, params[0])) == NULL) {
-    char error_buf[BUFSIZ];
-    sprintf(error_buf, "%s '%s'",
-	    "Xaw - SimpleMenuWidget: could not find menu named: ", params[0]);
-    XtAppWarning(XtWidgetToApplicationContext(w), error_buf);
+    if ((len = strlen (fmt) + strlen (params[0])) < sizeof error_buf) ebp = error_buf;
+    else ebp = XtMalloc (len + 1);
+    if (ebp == NULL) {
+      ebp = error_buf;
+      strcpy(ebp, "Xaw - SimpleMenuWidget: could not find menu");
+    }
+    else (void)sprintf(ebp, fmt, params[0]);
+
+    XtAppWarning(XtWidgetToApplicationContext(w), ebp);
+    if (ebp != error_buf) XtFree (ebp);
     return;
   }
   
@@ -676,7 +687,7 @@ Cardinal * num_params;
     PositionMenu(menu, &loc);
     break;
   default:
-    PositionMenu(menu, NULL);
+    PositionMenu(menu, (XPoint *)NULL);
     break;
   }
 }  
@@ -857,18 +868,14 @@ static void CreateLabel(w)
 Widget w;
 {
     SimpleMenuWidget smw = (SimpleMenuWidget) w;
-    register Widget * child, * next_child;
-    register int i;
+    Widget * child, * next_child;
+    int i;
     Arg args[2];
 
-    if ( (smw->simple_menu.label_string == NULL) ||
-	 (smw->simple_menu.label != NULL) ) {
-	char error_buf[BUFSIZ];
-
-	sprintf(error_buf, "Xaw Simple Menu Widget: %s or %s, %s",
-		"label string is NULL", "label already exists", 
-		"no label is being created.");
-	XtAppWarning(XtWidgetToApplicationContext(w), error_buf);
+    if ((smw->simple_menu.label_string == NULL) || (smw->simple_menu.label != NULL)) {
+	XtAppWarning(XtWidgetToApplicationContext(w),
+	 "Xaw Simple Menu Widget: Label string is NULL or label already exists.\n"
+	 "No label created.");
 	return;
     }
 
@@ -984,7 +991,7 @@ Dimension *width_ret, *height_ret;
 
 static void AddPositionAction(app_con, data)
 XtAppContext app_con;
-caddr_t data;
+XPointer data;
 {
     static XtActionsRec pos_action[] = {
         { "XawPositionSimpleMenu", PositionMenuAction },
@@ -1004,7 +1011,7 @@ static Widget FindMenu(widget, name)
 Widget widget;
 String name;
 {
-    register Widget w, menu;
+    Widget w, menu;
     
     for ( w = widget ; w != NULL ; w = XtParent(w) )
 	if ( (menu = XtNameToWidget(w, name)) != NULL )
@@ -1035,10 +1042,8 @@ XPoint * location;
 	location = &t_point;
 	if (XQueryPointer(XtDisplay(w), XtWindow(w), &junk1, &junk2, 
 			  &root_x, &root_y, &junkX, &junkY, &junkM) == FALSE) {
-	    char error_buf[BUFSIZ];
-	    sprintf(error_buf, "%s %s", "Xaw - SimpleMenuWidget:",
-		    "Could not find location of mouse pointer");
-	    XtAppWarning(XtWidgetToApplicationContext(w), error_buf);
+	   XtAppWarning(XtWidgetToApplicationContext(w),
+		"Xaw Simple Menu Widget: Could not find location of mouse pointer");
 	    return;
 	}
 	location->x = (short) root_x;
@@ -1183,7 +1188,7 @@ Widget w, w_ent;
 	if (!XtIsManaged( (Widget) *entry)) continue;
 	
 	if (*entry != cur_entry) {
-	    XtQueryGeometry((Widget) *entry, NULL, &preferred);
+	    XtQueryGeometry((Widget) *entry, (XtWidgetGeometry *)NULL, &preferred);
 	    
 	    if (preferred.request_mode & CWWidth)
 		width = preferred.width;
@@ -1337,4 +1342,6 @@ Widget w;
       XDrawLine(Dpy,  Win, simpleMenu->simple_menu.shadowGC, xMin, yMin, xMin, yMax);
       xMin++; yMin--; yMax++;
    }
-}
\ No newline at end of file
+}
+
+
