@@ -1,7 +1,25 @@
 /*
- * $XConsortium: Tree.c,v 1.42 91/02/20 20:06:07 converse Exp $
+ * $TOG: Tree.c /main/47 1998/02/11 14:56:05 kaleb $
  *
- * Copyright 1990 Massachusetts Institute of Technology
+
+Copyright 1990, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
  * Copyright 1989 Prentice Hall
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -9,9 +27,9 @@
  * copyright notice appear in all copies and that both the copyright notice
  * and this permission notice appear in supporting documentation.
  * 
- * M.I.T., Prentice Hall and the authors disclaim all warranties with regard
+ * Prentice Hall and the authors disclaim all warranties with regard
  * to this software, including all implied warranties of merchantability and
- * fitness.  In no event shall M.I.T., Prentice Hall or the authors be liable
+ * fitness.  In no event shall Prentice Hall or the authors be liable
  * for any special, indirect or cosequential damages or any damages whatsoever
  * resulting from loss of use, data or profits, whether in an action of
  * contract, negligence or other tortious action, arising out of or in
@@ -25,14 +43,12 @@
  * with Xt OSF/Motif Edition."  The layout code has been rewritten to use
  * additional blank space to make the structure of the graph easier to see
  * as well as to support vertical trees.
+ *
+ * This file contains modifications for XawPlus, Roland Krause 2000
  */
 
-#include <X11/Intrinsic.h>
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
-#include <X11/CoreP.h>
-#include <X11/CompositeP.h>
-#include <X11/ConstrainP.h>
 #include <X11/XawPlus/XawInit.h>
 #include <X11/XawPlus/Cardinals.h>
 #include <X11/XawPlus/TreeP.h>
@@ -64,6 +80,8 @@ static void             layout_tree();
  * resources of the tree itself
  */
 static XtResource resources[] = {
+    { XtNbackground, XtCBackground, XtRPixel, sizeof(Pixel),
+        XtOffsetOf(WidgetRec, core.background_pixel), XtRString, "grey75"},
     { XtNautoReconfigure, XtCAutoReconfigure, XtRBoolean, sizeof (Boolean),
 	XtOffsetOf(TreeRec, tree.auto_reconfigure), XtRImmediate,
 	(XtPointer) FALSE },
@@ -167,8 +185,8 @@ static void initialize_dimensions (listp, sizep, n)
     int *sizep;
     int n;
 {
-    register int i;
-    register Dimension *l;
+    int i;
+    Dimension *l;
 
     if (!*listp) {
 	*listp = (Dimension *) XtCalloc ((unsigned int) n,
@@ -297,17 +315,29 @@ static void check_gravity (tw, grav)
 
 static void ClassInitialize ()
 {
+   /* Arguments for the color converter */
+
+   static XtConvertArgRec colConvertArg[] = {
+     {XtWidgetBaseOffset, (XtPointer)XtOffsetOf(WidgetRec, core.screen), sizeof(Screen *)},
+     {XtWidgetBaseOffset, (XtPointer)XtOffsetOf(WidgetRec, core.colormap), sizeof(Colormap)}
+   };
+
     XawInitializeWidgetSet();
-    XtAddConverter (XtRString, XtRGravity, XmuCvtStringToGravity,
-		    (XtConvertArgList) NULL, (Cardinal) 0);
+    XtAddConverter(XtRString, XtRGravity, XmuCvtStringToGravity,
+		   (XtConvertArgList)NULL, (Cardinal)0);
+    XtSetTypeConverter(XtRString, XtRPixel, XtCvtStringToPixel,
+	 colConvertArg, XtNumber(colConvertArg), XtCacheByDisplay, NULL);
 }
 
 
-static void Initialize (grequest, gnew)
+/*ARGSUSED*/
+static void Initialize (grequest, gnew, args, num_args)
     Widget grequest, gnew;
+    ArgList args;
+    Cardinal *num_args;
 {
     TreeWidget request = (TreeWidget) grequest, new = (TreeWidget) gnew;
-    Arg args[2];
+    Arg arglist[2];
 
     /*
      * Make sure the widget's width and height are 
@@ -338,9 +368,10 @@ static void Initialize (grequest, gnew)
      * Create the hidden root widget.
      */
     new->tree.tree_root = (Widget) NULL;
-    XtSetArg(args[0], XtNwidth, 1);
-    XtSetArg(args[1], XtNheight, 1);
-    new->tree.tree_root = XtCreateWidget ("root", widgetClass, gnew, args,TWO);
+    XtSetArg(arglist[0], XtNwidth, 1);
+    XtSetArg(arglist[1], XtNheight, 1);
+    new->tree.tree_root = XtCreateWidget ("root", widgetClass, gnew,
+					  arglist,TWO);
 
     /*
      * Allocate the array used to hold the widest values per depth
@@ -358,8 +389,10 @@ static void Initialize (grequest, gnew)
 
 
 /* ARGSUSED */
-static void ConstraintInitialize (request, new)
+static void ConstraintInitialize (request, new, args, num_args)
      Widget request, new;
+     ArgList args;
+     Cardinal *num_args;
 {
     TreeConstraints tc = TREE_CONSTRAINT(new);
     TreeWidget tw = (TreeWidget) new->core.parent;
@@ -387,10 +420,11 @@ static void ConstraintInitialize (request, new)
 } 
 
 
-static Boolean SetValues(gcurrent, grequest, gnew, args, num_args)
-Widget gcurrent, grequest, gnew;
-ArgList args;
-Cardinal *num_args;
+/* ARGSUSED */
+static Boolean SetValues (gcurrent, grequest, gnew, args, num_args)
+    Widget gcurrent, grequest, gnew;
+    ArgList args;
+    Cardinal *num_args;
 {
     TreeWidget current = (TreeWidget) gcurrent, new = (TreeWidget) gnew;
     Boolean redraw = FALSE;
@@ -434,10 +468,11 @@ Cardinal *num_args;
 }
 
 
-static Boolean ConstraintSetValues(current, request, new, args, num_args)
-Widget current, request, new;
-ArgList args;
-Cardinal *num_args;
+/* ARGSUSED */
+static Boolean ConstraintSetValues (current, request, new, args, num_args)
+    Widget current, request, new;
+    ArgList args;
+    Cardinal *num_args;
 {
     TreeConstraints newc = TREE_CONSTRAINT(new);
     TreeConstraints curc = TREE_CONSTRAINT(current);
@@ -540,11 +575,13 @@ static void Destroy (gw)
 
 
 /* ARGSUSED */
-static void Redisplay (tw, event, region)
-     TreeWidget tw;
+static void Redisplay (gw, event, region)
+     Widget gw;
      XEvent *event;
      Region region;
 {
+    TreeWidget tw = (TreeWidget) gw;
+
     /*
      * If the Tree widget is visible, visit each managed child.
      */
@@ -554,7 +591,7 @@ static void Redisplay (tw, event, region)
 	Window w = XtWindow (tw);
 
 	for (i = 0; i < tw->composite.num_children; i++) {
-	    register Widget child = tw->composite.children[i];
+	    Widget child = tw->composite.children[i];
 	    TreeConstraints tc = TREE_CONSTRAINT(child);
 
 	    /*
@@ -581,7 +618,7 @@ static void Redisplay (tw, event, region)
 		}
 
 		for (j = 0; j < tc->tree.n_children; j++) {
-		    register Widget k = tc->tree.children[j];
+		    Widget k = tc->tree.children[j];
 		    GC gc = (tc->tree.gc ? tc->tree.gc : tw->tree.gc);
 
 		    switch (tw->tree.gravity) {
@@ -639,7 +676,7 @@ static XtGeometryResult QueryGeometry (w, intended, preferred)
     Widget w;
     XtWidgetGeometry *intended, *preferred;
 {
-    register TreeWidget tw = (TreeWidget) w;
+    TreeWidget tw = (TreeWidget) w;
 
     preferred->request_mode = (CWWidth | CWHeight);
     preferred->width = tw->tree.maxwidth;
@@ -675,7 +712,7 @@ static void compute_bounding_box_subtree (tree, w, depth)
     int depth;
 {
     TreeConstraints tc = TREE_CONSTRAINT(w);  /* info attached to all kids */
-    register int i;
+    int i;
     Bool horiz = IsHorizontal (tree);
     Dimension newwidth, newheight;
     Dimension bw2 = w->core.border_width * 2;
@@ -791,7 +828,7 @@ static void arrange_subtree (tree, w, depth, x, y)
 {
     TreeConstraints tc = TREE_CONSTRAINT(w);  /* info attached to all kids */
     TreeConstraints firstcc, lastcc;
-    register int i;
+    int i;
     int newx, newy;
     Bool horiz = IsHorizontal (tree);
     Widget child = NULL;
@@ -977,4 +1014,3 @@ XawTreeForceLayout (tree)
     layout_tree ((TreeWidget) tree, FALSE);
 }
 
-
