@@ -1,8 +1,27 @@
-/* $XConsortium: Command.h,v 1.27 91/07/28 18:51:35 converse Exp $ */
+/* $TOG: Command.h /main/30 1998/02/06 12:45:25 kaleb $ */
 
-/***********************************************************
-Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,
-and the Massachusetts Institute of Technology, Cambridge, Massachusetts.
+/************************************************************************
+
+Copyright 1987, 1988, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+
+Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
@@ -10,7 +29,7 @@ Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
 both that copyright notice and this permission notice appear in 
-supporting documentation, and that the names of Digital or MIT not be
+supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
 software without specific, written prior permission.  
 
@@ -22,11 +41,9 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
-Note:	At this time, I only support rectangular buttons. So the
-	the resources 'shapeStyle' and 'cornerRoundPercent' are
-	not longer supported.
+This file contains modifications for XawPlus, Roland Krause 2000
 
-******************************************************************/
+**************************************************************************/
 
 #ifndef _XawCommand_h
 #define _XawCommand_h
@@ -53,20 +70,20 @@ Note:	At this time, I only support rectangular buttons. So the
  background	     Background		Pixel		grey75
  mappedWhenManaged   MappedWhenManaged	Boolean		True
 
- ADD3DEXT:
- highlightColor	     Background		Pixel		grey90
- shadowColor	     Background		Pixel		grey40
- buttonBorderWidth   Width		Dimension	2
-
  SIMPLE:
  cursor		     Cursor		Cursor		None
  cursorName	     Cursor		String		NULL
  pointerColor        Foreground         Pixel           XtDefaultForeground
  pointerColorBackground Background      Pixel           XtDefaultBackground
  insensitiveBorder   Insensitive	Pixmap		Gray
+ international	     International      Boolean		False
+ highlightColor	     Background		Pixel		grey90
+ shadowColor	     Background		Pixel		grey40
+ buttonBorderWidth   Width		Dimension	2
 
  LABEL:
  font		     Font		XFontStruct*	XtDefaultFont
+ fontSet	     FontSet		FontSet		XtDefaultFontSet
  encoding	     Encoding		unsigned char	XawTextEncoding8bit
  foreground	     Foreground		Pixel		XtDefaultForeground
  internalHeight	     Height		Dimension	2
@@ -83,7 +100,6 @@ Note:	At this time, I only support rectangular buttons. So the
 
  COMMAND:
  helpText	     Label		String		NULL
- helpEncoding	     Encoding		unsigned char	XawTextEncoding8bit
  helpBackground	     Background		Pixel		LightGoldenrodYellow
  useHelp	     Boolean		Boolean		True
  highlightThickness  Thickness		Dimension	2
@@ -101,13 +117,28 @@ Note:	At this time, I only support rectangular buttons. So the
 #define XtNhighlightMode	"highlightMode"
 #define XtNuseHelp		"useHelp"
 #define XtNhelpText		"helpText"
-#define XtNhelpEncoding		"helpEncoding"
 #define XtNhelpBackground	"helpBackground"
+/*
+ * These resources are not supported in XawPlus.
+ * They are only provided for source compatibility
+ * to the original:
+ */
+#define XtNshapeStyle 		"shapeStyle"
+#define XtCShapeStyle 		"ShapeStyle"
+#define XtRShapeStyle 		"ShapeStyle"
+#define XtNcornerRoundPercent 	"cornerRoundPercent"
+#define XtCCornerRoundPercent 	"CornerRoundPercent"
 
-extern WidgetClass     commandWidgetClass;
+#define XawShapeRectangle 	XmuShapeRectangle
+#define XawShapeOval 		XmuShapeOval
+#define XawShapeEllipse 	XmuShapeEllipse
+#define XawShapeRoundedRectangle XmuShapeRoundedRectangle
 
-typedef struct _CommandClassRec   *CommandWidgetClass;
-typedef struct _CommandRec        *CommandWidget;
+
+extern WidgetClass 		commandWidgetClass;
+
+typedef struct _CommandClassRec *CommandWidgetClass;
+typedef struct _CommandRec      *CommandWidget;
 
 #endif /* _XawCommand_h */
 /* DON'T ADD STUFF AFTER THIS */
