@@ -1,8 +1,27 @@
-/* $XConsortium: Dialog.h,v 1.26 91/07/22 19:05:10 converse Exp $ */
+/* $TOG: Dialog.h /main/29 1998/02/06 12:45:41 kaleb $ */
 
-/***********************************************************
-Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts,
-and the Massachusetts Institute of Technology, Cambridge, Massachusetts.
+/************************************************************************
+
+Copyright 1987, 1988, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+
+Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
@@ -10,7 +29,7 @@ Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, 
 provided that the above copyright notice appear in all copies and that
 both that copyright notice and this permission notice appear in 
-supporting documentation, and that the names of Digital or MIT not be
+supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
 software without specific, written prior permission.  
 
@@ -22,15 +41,14 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
-Cleaned up the resource description: Roland Krause 1997
+This file contains modifications for XawPlus, Roland Krause 2000
 
-******************************************************************/
+************************************************************************/
 
 #ifndef _XawDialog_h
 #define _XawDialog_h
 
 #include <X11/XawPlus/Form.h>
-#include <X11/Xfuncproto.h>
 
 /***********************************************************************
  *
@@ -81,7 +99,7 @@ _XFUNCPROTOBEGIN
 extern void XawDialogAddButton(
 #if NeedFunctionPrototypes
     Widget		/* dialog */,
-    _Xconst char*	/* name */,
+    String		/* name */,
     XtCallbackProc	/* function */,
     XtPointer		/* client_data */
 #endif
@@ -96,4 +114,3 @@ extern char *XawDialogGetValueString(
 _XFUNCPROTOEND
 
 #endif /* _XawDialog_h */
-/* DON'T ADD STUFF AFTER THIS #endif */
