@@ -10,7 +10,6 @@
 #ifndef _DrawingAreaP_h
 #define _DrawingAreaP_h
 
-#include <X11/XawPlus/Add3dExtP.h>
 #include <X11/XawPlus/SimpleP.h>
 #include <X11/XawPlus/DrawingArea.h>
 
@@ -23,7 +22,6 @@ typedef struct {int foo;} DrawingAreaClassPart;
 
 typedef struct _DrawingAreaClassRec {
     CoreClassPart		core_class;
-    Add3dExtClassPart		add3d_class;
     SimpleClassPart		simple_class;
     DrawingAreaClassPart	drawingArea_class;
 } DrawingAreaClassRec;
@@ -52,7 +50,6 @@ typedef struct {
 
 typedef struct _DrawingAreaRec {
     CorePart		core;
-    Add3dExtPart	add3dExt;
     SimplePart		simple;
     DrawingAreaPart	draw;
 } DrawingAreaRec;
