@@ -1,25 +1,27 @@
 /*
- * $XConsortium: MenuButton.h,v 1.7 89/12/11 14:57:44 kit Exp $
+ * $TOG: MenuButton.h /main/11 1998/02/11 14:53:37 kaleb $
  *
- * Copyright 1989 Massachusetts Institute of Technology
- *
- * Permission to use, copy, modify, distribute, and sell this software and its
- * documentation for any purpose is hereby granted without fee, provided that
- * the above copyright notice appear in all copies and that both that
- * copyright notice and this permission notice appear in supporting
- * documentation, and that the name of M.I.T. not be used in advertising or
- * publicity pertaining to distribution of the software without specific,
- * written prior permission.  M.I.T. makes no representations about the
- * suitability of this software for any purpose.  It is provided "as is"
- * without express or implied warranty.
- *
- * M.I.T. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL M.I.T.
- * BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
- * OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
- * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- */
+Copyright 1989, 1994, 1998  The Open Group
+
+All Rights Reserved.
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
+OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
+AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of The Open Group shall not be
+used in advertising or otherwise to promote the sale, use or other dealings
+in this Software without prior written authorization from The Open Group.
+
+This file contains modifications for XawPlus, Roland Krause 2000
+
+*/
 
 /***********************************************************************
  *
@@ -65,20 +67,20 @@
  background	     Background		Pixel		grey75
  mappedWhenManaged   MappedWhenManaged	Boolean		True
 
- ADD3DEXT:
- highlightColor	     Background		Pixel		grey90
- shadowColor	     Background		Pixel		grey40
- buttonBorderWidth   Width		Dimension	2
-
  SIMPLE:
  cursor		     Cursor		Cursor		None
  cursorName	     Cursor		String		NULL
  pointerColor        Foreground         Pixel           XtDefaultForeground
  pointerColorBackground Background      Pixel           XtDefaultBackground
  insensitiveBorder   Insensitive	Pixmap		Gray
+ international	     International      Boolean		False
+ highlightColor	     Background		Pixel		grey90
+ shadowColor	     Background		Pixel		grey40
+ buttonBorderWidth   Width		Dimension	2
 
  LABEL:
  font		     Font		XFontStruct*	XtDefaultFont
+ fontSet	     FontSet		FontSet		XtDefaultFontSet
  encoding	     Encoding		unsigned char	XawTextEncoding8bit
  foreground	     Foreground		Pixel		XtDefaultForeground
  internalHeight	     Height		Dimension	2
@@ -115,4 +117,4 @@ extern WidgetClass     menuButtonWidgetClass;
 typedef struct _MenuButtonClassRec   *MenuButtonWidgetClass;
 typedef struct _MenuButtonRec        *MenuButtonWidget;
 
-#endif /* _XawMenuButton_h --  DON'T ADD STUFF AFTER THIS */
+#endif /* _XawMenuButton_h */
